changeset 15357:15e6f35b4223 v8.1.0686

patch 8.1.0686: when 'y' is in 'cpoptions' yanking for the clipboard changes redo commit https://github.com/vim/vim/commit/5823f84dd04198994e3e5f2e278a5e315c47d32d Author: Bram Moolenaar <Bram@vim.org> Date: Thu Jan 3 22:58:08 2019 +0100 patch 8.1.0686: when 'y' is in 'cpoptions' yanking for the clipboard changes redo Problem: When 'y' is in 'cpoptions' yanking for the clipboard changes redo. Solution: Do not use the 'y' flag when "gui_yank" is TRUE. (Andy Massimino, closes #3760)
author Bram Moolenaar <Bram@vim.org>
date Thu, 03 Jan 2019 23:00:11 +0100
parents d717fbf430b9
children 48d115da20a8
files src/normal.c src/version.c
diffstat 2 files changed, 10 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -800,6 +800,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    686,
+/**/
     685,
 /**/
     684,
--- a/src/normal.c
+++ b/src/normal.c
@@ -1326,7 +1326,8 @@ set_vcount_ca(cmdarg_T *cap, int *set_pr
 #endif
 
 /*
  * Handle an operator after visual mode or when the movement is finished
  */
     void
 do_pending_operator(cmdarg_T *cap, int old_col, int gui_yank)
@@ -1372,6 +1373,10 @@ do_pending_operator(cmdarg_T *cap, int o
      */
     if ((finish_op || VIsual_active) && oap->op_type != OP_NOP)
     {
+	// Yank can be redone when 'y' is in 'cpoptions', but not when yanking
+	// for the clipboard.
+	int	redo_yank = vim_strchr(p_cpo, CPO_YANK) != NULL && !gui_yank;
+
 #ifdef FEAT_LINEBREAK
 	/* Avoid a problem with unwanted linebreaks in block mode. */
 	if (curwin->w_p_lbr)
@@ -1407,7 +1412,7 @@ do_pending_operator(cmdarg_T *cap, int o
 
 	/* Only redo yank when 'y' flag is in 'cpoptions'. */
 	/* Never redo "zf" (define fold). */
-	if ((vim_strchr(p_cpo, CPO_YANK) != NULL || oap->op_type != OP_YANK)
+	if ((redo_yank || oap->op_type != OP_YANK)
 		&& ((!VIsual_active || oap->motion_force)
 		    /* Also redo Operator-pending Visual mode mappings */
 		    || (VIsual_active && cap->cmdchar == ':'
@@ -1628,7 +1633,7 @@ do_pending_operator(cmdarg_T *cap, int o
 	    }
 
 	    /* can't redo yank (unless 'y' is in 'cpoptions') and ":" */
-	    if ((vim_strchr(p_cpo, CPO_YANK) != NULL || oap->op_type != OP_YANK)
+	    if ((redo_yank || oap->op_type != OP_YANK)
 		    && oap->op_type != OP_COLON
 #ifdef FEAT_FOLDING
 		    && oap->op_type != OP_FOLD
@@ -1326,7 +1326,8 @@ set_vcount_ca(cmdarg_T *cap, int *set_pr
 
 /*
- * Handle an operator after visual mode or when the movement is finished
+ * Handle an operator after Visual mode or when the movement is finished.
+ * "gui_yank" is true when yanking text for the clipboard.
  */
     void